@@ -2,6 +2,8 @@ from .bot import *
 from .core import *
 from .context import *
 from .cog import *
+from .enums import *
+from .modal import *
 
 from ._patch import inject
 inject()
